#ifndef NT2_INCLUDE_FUNCTIONS_MODULO_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_MODULO_HPP_INCLUDED

#include <nt2/operator/include/functions/modulo.hpp>

#endif
